@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,13 +20,13 @@
 */
 
 #include "constraint.h"
+#include "utilsns.h"
 
 Constraint::Constraint()
 {
 	ref_table=nullptr;
 	obj_type=ObjectType::Constraint;
-	deferrable=false;
-	no_inherit=false;
+	deferrable=no_inherit=nulls_not_distinct = false;
 	fill_factor=0;
 	index_type=IndexingType::Null;
 
@@ -48,6 +51,7 @@ Constraint::Constraint()
 	attributes[Attributes::Factor]="";
 	attributes[Attributes::NoInherit]="";
 	attributes[Attributes::Elements]="";
+	attributes[Attributes::NullsNotDistinct]="";
 }
 
 Constraint::~Constraint()
@@ -190,10 +194,10 @@ void Constraint::addColumns(const std::vector<Column *> &cols, ColumnsId cols_id
 {
 	try
 	{
-		if(cols_id == ReferencedCols)
-			ref_columns.clear();
-		else
+		if(cols_id == SourceCols)
 			columns.clear();
+		else
+			ref_columns.clear();
 
 		for(auto &col : cols)
 			addColumn(col, cols_id);
@@ -264,9 +268,9 @@ void Constraint::setColumnsAttribute(ColumnsId cols_id, unsigned def_type, bool
 	attributes[attrib]=str_cols;
 }
 
-void Constraint::setReferencedTable(BaseTable *tab_ref)
+void Constraint::setReferencedTable(BaseTable *ref_tab)
 {
-	this->ref_table=tab_ref;
+	this->ref_table = ref_tab;
 }
 
 void Constraint::setDeferralType(DeferralType deferral_type)
@@ -429,70 +433,61 @@ bool Constraint::isNoInherit()
 	return no_inherit;
 }
 
-bool Constraint::isReferRelationshipAddedColumn()
+bool Constraint::isReferRelationshipAddedColumns(const std::vector<Column *> &cols)
 {
-	std::vector<Column *>::iterator itr, itr_end;
-	std::vector<ExcludeElement>::iterator itr1, itr1_end;
-	Column *col=nullptr;
-	bool found=false;
+	std::vector<Column *> rel_cols = getRelationshipAddedColumns(cols.empty());
 
-	//First iterates over the source columns list
-	itr=columns.begin();
-	itr_end=columns.end();
-
-	while(itr!=itr_end && !found)
+	if(!cols.empty())
 	{
-		col=(*itr);
-		//Check if the current column were added by relationship
-		found=col->isAddedByRelationship();
-		itr++;
+		auto find_cols = [&rel_cols, &cols]() {
+			for(auto &col : cols)
+			{
+				if(std::find(rel_cols.begin(), rel_cols.end(), col) != rel_cols.end())
+					return true;
+			}
 
-		/* Case the source column list is completely iterated steps to
-		 the referenced columns list iteration */
-		if(itr==itr_end && itr_end!=ref_columns.end() && !found)
-		{
-			itr=ref_columns.begin();
-			itr_end=ref_columns.end();
-		}
+			return false;
+		};
+
+		return find_cols();
 	}
 
-	//Iterates over the exclude elements
-	itr1=excl_elements.begin();
-	itr1_end=excl_elements.end();
+	return !rel_cols.empty();
+}
 
-	while(itr1!=itr1_end && !found)
+std::vector<Column *> Constraint::getRelationshipAddedColumns(bool first_col_only)
+{
+	std::vector<Column *> rel_cols;
+	Column *col = nullptr;
+
+	std::for_each(columns.begin(), columns.end(), [&rel_cols](auto &col) {
+		if(col->isAddedByRelationship())
+			rel_cols.push_back(col);
+	});
+
+	if(!first_col_only || (first_col_only && rel_cols.empty()))
 	{
-		col=(*itr1).getColumn();
-		found=(col && col->isAddedByRelationship());
-		itr1++;
+		std::for_each(ref_columns.begin(), ref_columns.end(), [&rel_cols](auto &col) {
+			if(col->isAddedByRelationship())
+				rel_cols.push_back(col);
+		});
 	}
 
-	return found;
+	if(!first_col_only || (first_col_only && rel_cols.empty()))
+	{
+		std::for_each(excl_elements.begin(), excl_elements.end(), [&rel_cols, &col](auto &elem) {
+			col = elem.getColumn();
+			if(col && col->isAddedByRelationship())
+				rel_cols.push_back(col);
+		});
+	}
+
+	return rel_cols;
 }
 
 std::vector<Column *> Constraint::getRelationshipAddedColumns()
 {
-	Column *column=nullptr;
-	std::vector<Column *> cols;
-	std::vector<std::vector<Column *> *> lists = { &columns, &ref_columns };
-
-	for(auto &p_lst : lists)
-	{
-		for(auto &col : (*p_lst))
-		{
-			if(col->isAddedByRelationship())
-				cols.push_back(col);
-		}
-	}
-
-	for(auto &excl_elem : excl_elements)
-	{
-		column=excl_elem.getColumn();
-		if(column && column->isAddedByRelationship())
-			cols.push_back(column);
-	}
-
-	return cols;
+	return getRelationshipAddedColumns(false);
 }
 
 MatchType Constraint::getMatchType()
@@ -500,7 +495,6 @@ MatchType Constraint::getMatchType()
 	return match_type;
 }
 
-
 int Constraint::getExcludeElementIndex(ExcludeElement elem)
 {
 	int idx=0;
@@ -522,18 +516,22 @@ std::vector<ExcludeElement> Constraint::getExcludeElements()
 
 void Constraint::addExcludeElements(std::vector<ExcludeElement> &elems)
 {
-	std::vector<ExcludeElement> elems_bkp=excl_elements;
+	std::vector<ExcludeElement> elems_bkp = excl_elements;
 
 	try
 	{
-		excl_elements.clear();
+		removeExcludeElements();
 
-		for(unsigned i=0; i < elems.size(); i++)
-			addExcludeElement(elems[i]);
+		for(auto &elem : elems)
+			addExcludeElement(elem);
 	}
 	catch(Exception &e)
 	{
-		excl_elements = elems_bkp;
+		removeExcludeElements();
+
+		for(auto &elem : elems_bkp)
+			addExcludeElement(elem);
+
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
@@ -550,78 +548,6 @@ void Constraint::addExcludeElement(ExcludeElement elem)
 	setCodeInvalidated(true);
 }
 
-void Constraint::addExcludeElement(const QString &expr, Operator *oper, OperatorClass *op_class, bool use_sorting, bool asc_order, bool nulls_first)
-{
-	try
-	{
-		ExcludeElement elem;
-
-		//Raises an error if the expression is empty
-		if(expr.isEmpty())
-			throw Exception(ErrorCode::AsgInvalidExpressionObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-		//Configures the element
-		elem.setExpression(expr);
-		elem.setOperatorClass(op_class);
-		elem.setOperator(oper);
-		elem.setSortingEnabled(use_sorting);
-		elem.setSortingAttribute(ExcludeElement::NullsFirst, nulls_first);
-		elem.setSortingAttribute(ExcludeElement::AscOrder, asc_order);
-
-		if(getExcludeElementIndex(elem) >= 0)
-			throw Exception(ErrorCode::InsDuplicatedElement,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-		excl_elements.push_back(elem);
-		setCodeInvalidated(true);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
-}
-
-void Constraint::addExcludeElement(Column *column, Operator *oper, OperatorClass *op_class, bool use_sorting, bool asc_order, bool nulls_first)
-{
-	try
-	{
-		ExcludeElement elem;
-
-		//Case the column is not allocated raises an error
-		if(!column)
-			throw Exception(Exception::getErrorMessage(ErrorCode::AsgNotAllocatedColumn)
-							.arg(this->getName())
-							.arg(this->getTypeName()),
-							ErrorCode::AsgNotAllocatedColumn,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-		//Configures the element
-		elem.setColumn(column);
-		elem.setOperatorClass(op_class);
-		elem.setOperator(oper);
-		elem.setSortingEnabled(use_sorting);
-		elem.setSortingAttribute(ExcludeElement::NullsFirst, nulls_first);
-		elem.setSortingAttribute(ExcludeElement::AscOrder, asc_order);
-
-		if(getExcludeElementIndex(elem) >= 0)
-			throw Exception(ErrorCode::InsDuplicatedElement,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-		excl_elements.push_back(elem);
-		setCodeInvalidated(true);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
-}
-
-void Constraint::removeExcludeElement(unsigned elem_idx)
-{
-	if(elem_idx >= excl_elements.size())
-		throw Exception(ErrorCode::RefElementInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-	excl_elements.erase(excl_elements.begin() + elem_idx);
-	setCodeInvalidated(true);
-}
-
 void Constraint::removeExcludeElements()
 {
 	excl_elements.clear();
@@ -633,13 +559,21 @@ void Constraint::setColumnsNotNull(bool value)
 	if(constr_type==ConstraintType::PrimaryKey)
 	{
 		for(auto &col : columns)
-		{
-			//if(!col->isAddedByRelationship())
 			col->setNotNull(value);
-		}
 	}
 }
 
+void Constraint::setNullsNotDistinct(bool value)
+{
+	setCodeInvalidated(nulls_not_distinct != value);
+	nulls_not_distinct = value;
+}
+
+bool Constraint::isNullsNotDistinct()
+{
+	return nulls_not_distinct;
+}
+
 ExcludeElement Constraint::getExcludeElement(unsigned elem_idx)
 {
 	if(elem_idx >= excl_elements.size())
@@ -687,7 +621,7 @@ void Constraint::setDeclInTableAttribute()
 {
 	if(!isDeclaredInTable() || (constr_type==ConstraintType::ForeignKey && !isAddedByLinking()))
 		attributes[Attributes::DeclInTable]="";
-	else if(!isReferRelationshipAddedColumn() || constr_type==ConstraintType::PrimaryKey)
+	else if(!isReferRelationshipAddedColumns() || constr_type==ConstraintType::PrimaryKey)
 		attributes[Attributes::DeclInTable]=Attributes::True;
 }
 
@@ -703,8 +637,8 @@ void Constraint::configureSearchAttributes()
 	for(auto &col : ref_columns)
 		ref_col_names.append(col->getSignature());
 
-	search_attribs[Attributes::SrcColumns] = src_col_names.join(", ");
-	search_attribs[Attributes::RefColumns] = ref_col_names.join(", ");
+	search_attribs[Attributes::SrcColumns] = src_col_names.join(UtilsNs::DataSeparator);
+	search_attribs[Attributes::RefColumns] = ref_col_names.join(UtilsNs::DataSeparator);
 }
 
 QString Constraint::getSourceCode(SchemaParser::CodeType def_type, bool inc_addedbyrel)
@@ -764,6 +698,7 @@ QString Constraint::getSourceCode(SchemaParser::CodeType def_type, bool inc_adde
 	attributes[Attributes::RefTable]=(ref_table ? ref_table->getName(true) : "");
 	attributes[Attributes::Deferrable]=(deferrable ? Attributes::True : "");
 	attributes[Attributes::NoInherit]=(no_inherit ? Attributes::True : "");
+	attributes[Attributes::NullsNotDistinct]=(nulls_not_distinct ? Attributes::True : "");
 	attributes[Attributes::ComparisonType]=(~match_type);
 	attributes[Attributes::DeferType]=(~deferral_type);
 	attributes[Attributes::IndexType]=(~ index_type);
@@ -787,7 +722,7 @@ QString Constraint::getDropCode(bool cascade)
 	return TableObject::getDropCode(cascade);
 }
 
-QString Constraint::getDataDictionary(const attribs_map &extra_attribs)
+QString Constraint::getDataDictionary(bool md_format, const attribs_map &extra_attribs)
 {
 	try
 	{
@@ -800,6 +735,8 @@ QString Constraint::getDataDictionary(const attribs_map &extra_attribs)
 		attribs[Attributes::Comment] = comment;
 		attribs[Attributes::RefTable] = ref_table ? ref_table->getSignature().remove('"') : "";
 		attribs[Attributes::Expression] = expression;
+		attribs[Attributes::UpdAction] = ~upd_action;
+		attribs[Attributes::DelAction] = ~del_action;
 
 		// Retrieving the columns that composes the constraint
 		for(auto &col : columns)
@@ -808,8 +745,7 @@ QString Constraint::getDataDictionary(const attribs_map &extra_attribs)
 		attribs[Attributes::Columns] = col_names.join(", ");
 
 		schparser.ignoreEmptyAttributes(true);
-		return schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
-																																					 getSchemaName()), attribs);
+		return schparser.getSourceCode(GlobalAttributes::getDictSchemaFilePath(md_format, getSchemaName()), attribs);
 	}
 	catch(Exception &e)
 	{
@@ -835,3 +771,20 @@ bool Constraint::isCodeDiffersFrom(BaseObject *object, const QStringList &ignore
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
 }
+
+void Constraint::updateDependencies()
+{
+	std::vector<BaseObject *> deps, aux_deps;
+
+	deps.insert(deps.end(), columns.begin(), columns.end());
+	deps.insert(deps.end(), ref_columns.begin(), ref_columns.end());
+	deps.push_back(ref_table);
+
+	for(auto &elem : excl_elements)
+	{
+		aux_deps = elem.getDependencies();
+		deps.insert(deps.end(), aux_deps.begin(), aux_deps.end());
+	}
+
+	TableObject::updateDependencies(deps);
+}
